==> mx-cleanup_19.4.tar.xz: mx-cleanup-19.4/translations/mx-cleanup_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="51"/>
        <location filename="../mainwindow.cpp" line="262"/>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>MX Cleanup</source>
        <translation>MX Temizleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Temizlenecek Klasörler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Delete Logs</source>
        <translation>Günlükleri Sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Old logs</source>
        <translation>Eski günlükler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>All logs</source>
        <translation>Tüm günlükler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="130"/>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Don&apos;t empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Empty Trash</source>
        <translation>Çöpü Boşalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Selected user</source>
        <translation>Seçilen kullanıcı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>All users</source>
        <translation>Tüm kullanıcılar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Clear APT Cache</source>
        <translation>APT önbelleğini temizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>Old files</source>
        <translation>Eski dosyalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>Free Disk Space for User</source>
        <translation>Kullanıcı için boş disk alanı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Select user to repair</source>
        <translation>Onarılacak kullanıcıyı seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Select user:</source>
        <translation>Kullanıcı seç:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="524"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Disk Kullanım İncelemesi için Grafiksel Araç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Disk Kullanım Çözümleyicisini Çalıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>Schedule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>No automatic clean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Done</source>
        <translation>Biti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Cleanup command done</source>
        <translation>Temizleme komutu tamamlandı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MB serbest bırakıldı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Quick and safe removal of old files</source>
        <translation>Eski dosyaların hızlı ve güvenli şekilde kaldırılması</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="266"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Bu programı root olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>

==> mx-cleanup_20.8.tar.xz: mx-cleanup-20.8/translations/mx-cleanup_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="324"/>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>MX Cleanup</source>
        <translation>MX Temizleyici</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Temizlenecek Klasörler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Çöpü Boşalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Boşaltma</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Tüm kullanıcılar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Seçilen kullanıcı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>APT önbelleğini temizle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Eski dosyalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Tüm dosyalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Free Disk Space for User</source>
        <translation>Kullanıcı için boş disk alanı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to repair</source>
        <translation>Onarılacak kullanıcıyı seçin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Select user:</source>
        <translation>Kullanıcı seç:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Disk Kullanım İncelemesi için Grafiksel Araç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Disk Kullanım Çözümleyicisini Çalıştır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Schedule</source>
        <translation>Çizelge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>No automatic clean</source>
        <translation>Otomatik Temizleme Olmasın</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Daily</source>
        <translation>Günlük</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Weekly</source>
        <translation>Haftalık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <source>Monthly</source>
        <translation>Aylık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Günlükleri Sil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Tüm günlükler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Eski günlükler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Done</source>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>Cleanup command done</source>
        <translation>Temizleme komutu tamamlandı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MB serbest bırakıldı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Quick and safe removal of old files</source>
        <translation>Eski dosyaların hızlı ve güvenli şekilde kaldırılması</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="329"/>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="345"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Bu programı root olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
